# -*- coding: utf-8 -*-
#
# dsbench/tpcbDefs.py - Definitions
#
# Copyright (C) 2014-2015 Rajko Thon <rajko.thon@leitstern.de>
#                         Mathias Ball <meb@leitstern.de>
#
# DSBench is free software: you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# You must obey the GNU Lesser General Public License in all respects for
# all of the code used.
#
# DSBench is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
# License for more details.
#

import collections


# i18n preparations.
def _(s):
    return s


# Constants
NAME = "dsbench"
GUARDFILE = "dsbench.log"
NOTHING = _("nothing")
UNKNOWN = _("unknown")
NOTACCENSSIBLE = _("not accessible")
NOTINSTALLED = _("not installed")
TRANSTYPE = _("Type of transaction")
NUMBERNODES = _("Number of nodes")
NUMBERTHREADS = _("Number of threads per node")
NUMBERCLIENTS = _("Number of connections per thread")
SCALINGFACTOR = _("scaling factor")
DATABASESIZE = _("database size [GB]")
LOCALTUPLE = ("localhost", "127.0.0.1", ":1")
SELECTNODE = _("Node '%s' at '%s' selected for remote transactions.")
MSGFROMNODE = _("Message received from node '%s': '%s'.")
ERRNODECLOSED = _("Connection to node '%s' closed unexpectedly.")
ERRSAVERESULTS = _("Could not save results to '%s'. Error message: '%s'.")
ERRREADRESULTS = _("Could not read results from '%s'. Error message: '%s'.")
ERRGNUPLOT = _("Could not create gnuplot script to '%s'. Error message: '%s'.")
ERRREADPLOT = _("Could not read gnuplot script from '%s'. Error message: '%s'")
GB = 1024.0 * 1024.0 * 1024.0
BUFSIZE = 8192
BLOCKSIZE = 100000
REDUCEOFFSET = 100
SENDDELAY = 2
TIMEOUT = 5
TIMEFACTOR = 16
COLUMN = 13


# Named tuple definitions:

# TransactionType:
# Transaction type definitions.
# ID - unique identification
# descr - description
# symbol - symbolic name as string
# func - name of PL/SQL function to be run for one transaction
tpcbTransType = collections.namedtuple(
    'tpcbTransType',
    'ID descr symbol func')

# Results:
# Transaction test results of one cycle, node and thread.
# ID - node identification as string
# done - number of transactions done successfully
# errors - number of transactions rolled back due to collision
# residence - total transaction residence time
# elapsed - effective transaction cycle duration
# tpsR - transaction rate based on residence time
# tpsE - transaction rate based on effective duration
# tpsD - transaction rate based on demanded duration
tpcbResults = collections.namedtuple(
    'tpcbResults',
    'ID done errors residence elapsed tpsR tpsE tpsD')

# DatabaseParameter:
# Database parameter for test sheet and diagram.
tpcbDbPar = collections.namedtuple(
    'tpcbDbPar',
    'title value')

# Marks:
# Memory size and label for marks in the diagram.
tpcbMarker = collections.namedtuple(
    'tpcbMarker',
    'gb text')

# TimeData:
# Column number and label for a legend of the table containing results.
tpcbTimeData = collections.namedtuple(
    'tpcbTimeData',
    'nr text')


# Transaction type constants
TPCB_DEFAULT = 0
TPCB_SELECT = 1
tpcbTransTable = {
    TPCB_DEFAULT:
    tpcbTransType(ID="TPC-B", descr="TPC-B", symbol="TPCB_DEFAULT",
                  func="tpcb_func_p_work"),
    TPCB_SELECT:
    tpcbTransType(ID="SELECT", descr="TPC-B (select only)",
                  symbol="TPCB_SELECT", func="tpcb_func_p_work_select")}
